@@ -15,17 +15,18 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include "aclmanager.h"
 #include "collectionaclwidget.h"
 #include "acllistview.h"
+#include "aclmanager.h"
 
 #include <KLocalizedString>
-#include <QVBoxLayout>
+
 #include <QAction>
 #include <QActionEvent>
+#include <QCheckBox>
 #include <QHBoxLayout>
 #include <QPushButton>
-#include <QCheckBox>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 /**
@@ -36,8 +37,8 @@ class ActionButton : public QPushButton
 {
 public:
     ActionButton(QWidget *parent = nullptr)
-        : QPushButton(parent),
-          mDefaultAction(nullptr)
+        : QPushButton(parent)
+        , mDefaultAction(nullptr)
     {
     }
 
@@ -55,10 +56,10 @@ public:
     }
 
 protected:
-    void actionEvent(QActionEvent *event) override {
+    void actionEvent(QActionEvent *event) override
+    {
         QAction *action = event->action();
-        switch (event->type())
-        {
+        switch (event->type()) {
         case QEvent::ActionChanged:
             if (action == mDefaultAction) {
                 setDefaultAction(mDefaultAction);
@@ -73,12 +74,12 @@ protected:
     }
 
 private:
-    QAction *mDefaultAction;
+    QAction *mDefaultAction = nullptr;
 };
 
 CollectionAclWidget::CollectionAclWidget(QWidget *parent)
-    : QWidget(parent),
-      mAclManager(new PimCommon::AclManager(this))
+    : QWidget(parent)
+    , mAclManager(new PimCommon::AclManager(this))
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
     QVBoxLayout *listViewLayout = new QVBoxLayout;
@@ -125,7 +126,6 @@ CollectionAclWidget::CollectionAclWidget(QWidget *parent)
 
 CollectionAclWidget::~CollectionAclWidget()
 {
-
 }
 
 void CollectionAclWidget::slotCollectionCanBeAdministrated(bool b)
