@@ -38,8 +38,8 @@ SelectMultiCollectionWidget::SelectMultiCollectionWidget(const QString &mimetype
 }
 
 SelectMultiCollectionWidget::SelectMultiCollectionWidget(const QString &mimetype, const QList<Akonadi::Collection::Id> &selectedCollection, QWidget *parent)
-    : QWidget(parent),
-      mListCollection(selectedCollection)
+    : QWidget(parent)
+    , mListCollection(selectedCollection)
 {
     initialize(mimetype);
 }
@@ -68,8 +68,8 @@ void SelectMultiCollectionWidget::updateStatus(const QModelIndex &parent)
     for (int i = 0; i < nbCol; ++i) {
         const QModelIndex child = mCheckedCollectionWidget->checkableProxy()->index(i, 0, parent);
 
-        const Akonadi::Collection col =
-            mCheckedCollectionWidget->checkableProxy()->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const Akonadi::Collection col
+            = mCheckedCollectionWidget->checkableProxy()->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
         if (mListCollection.contains(col.id())) {
             mCheckedCollectionWidget->checkableProxy()->setData(child, Qt::Checked, Qt::CheckStateRole);
@@ -94,8 +94,8 @@ QVector<Akonadi::Collection> SelectMultiCollectionWidget::selectedCollection(con
     for (int i = 0; i < nbCol; ++i) {
         const QModelIndex child = mCheckedCollectionWidget->checkableProxy()->index(i, 0, parent);
 
-        const Akonadi::Collection col =
-            mCheckedCollectionWidget->checkableProxy()->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+        const Akonadi::Collection col
+            = mCheckedCollectionWidget->checkableProxy()->data(child, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
 
         if (mCheckedCollectionWidget->checkableProxy()->data(child, Qt::CheckStateRole).value<int>()) {
             lst << col;
@@ -104,4 +104,3 @@ QVector<Akonadi::Collection> SelectMultiCollectionWidget::selectedCollection(con
     }
     return lst;
 }
-
