@@ -45,20 +45,18 @@ class Q_DECL_HIDDEN AnnotationEditDialog::Private
 {
 public:
     Private()
-        : mTextEdit(nullptr),
-          mNoteType(nullptr),
-          mHasAnnotation(false)
     {
     }
 
     Akonadi::Item mItem;
-    KPIMTextEdit::PlainTextEditorWidget *mTextEdit;
-    KComboBox *mNoteType;
-    bool mHasAnnotation;
+    KPIMTextEdit::PlainTextEditorWidget *mTextEdit = nullptr;
+    KComboBox *mNoteType = nullptr;
+    bool mHasAnnotation = false;
 };
 
 AnnotationEditDialog::AnnotationEditDialog(const Akonadi::Item &item, QWidget *parent)
-    : QDialog(parent), d(new Private)
+    : QDialog(parent)
+    , d(new Private)
 {
     d->mItem = item;
     //check for correct key?
@@ -143,9 +141,9 @@ void AnnotationEditDialog::slotAccepted()
 void AnnotationEditDialog::slotDeleteNote()
 {
     const int answer = KMessageBox::warningContinueCancel(this,
-                       i18n("Do you really want to delete this note?"),
-                       i18nc("@title:window", "Delete Note?"),
-                       KStandardGuiItem::del());
+                                                          i18n("Do you really want to delete this note?"),
+                                                          i18nc("@title:window", "Delete Note?"),
+                                                          KStandardGuiItem::del());
     if (answer == KMessageBox::Continue) {
         d->mItem.removeAttribute<Akonadi::EntityAnnotationsAttribute>();
         new Akonadi::ItemModifyJob(d->mItem);
@@ -169,4 +167,3 @@ void AnnotationEditDialog::writeConfig()
     KConfigGroup group(cfg, "AnnotationEditDialog");
     group.writeEntry("Size", size());
 }
-
